@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Bakerloo;
 
-$Map::Tube::London::Line::Bakerloo::VERSION   = '0.43';
+$Map::Tube::London::Line::Bakerloo::VERSION   = '0.44';
 $Map::Tube::London::Line::Bakerloo::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Bakerloo - London Tube Map Bakerloo Line stations.
 
 =head1 VERSION
 
-Version 0.43
+Version 0.44
 
 =head1 DESCRIPTION
 
@@ -70,7 +70,8 @@ London Tube Map Bakerloo Line stations.
 
 =head1 MAP
 
-London Metro: Bakerloo line map generated by plugin L<Map::Tube::Plugin::Graph>.
+London Metro: L<Bakerloo|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Bakerloo.png>
+line map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
