@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Central;
 
-$Map::Tube::London::Line::Central::VERSION   = '0.43';
+$Map::Tube::London::Line::Central::VERSION   = '0.44';
 $Map::Tube::London::Line::Central::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Central - London Tube Map Central Line stations.
 
 =head1 VERSION
 
-Version 0.43
+Version 0.44
 
 =head1 DESCRIPTION
 
@@ -92,7 +92,8 @@ London Tube Map Central Line stations.
 
 =head1 MAP
 
-London Metro: Central line map generated by plugin L<Map::Tube::Plugin::Graph>.
+London Metro: L<Central|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Central.png>
+line map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
