@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Circle;
 
-$Map::Tube::London::Line::Circle::VERSION   = '0.43';
+$Map::Tube::London::Line::Circle::VERSION   = '0.44';
 $Map::Tube::London::Line::Circle::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Circle - London Tube Map Circle Line stations.
 
 =head1 VERSION
 
-Version 0.43
+Version 0.44
 
 =head1 DESCRIPTION
 
@@ -101,7 +101,8 @@ London Tube Map Circle Line stations.
 
 =head1 MAP
 
-London Metro: Circle line map generated by plugin L<Map::Tube::Plugin::Graph>.
+London Metro: L<Circle|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Circle.png>
+line map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
