@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::District;
 
-$Map::Tube::London::Line::District::VERSION   = '0.43';
+$Map::Tube::London::Line::District::VERSION   = '0.44';
 $Map::Tube::London::Line::District::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::District - London Tube Map District Line stations.
 
 =head1 VERSION
 
-Version 0.43
+Version 0.44
 
 =head1 DESCRIPTION
 
@@ -130,7 +130,8 @@ London Tube Map District Line stations.
 
 =head1 MAP
 
-London Metro: District line map generated by plugin L<Map::Tube::Plugin::Graph>.
+London Metro: L<District|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/District.png>
+line map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
