@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::HammersmithCity;
 
-$Map::Tube::London::Line::HammersmithCity::VERSION   = '0.43';
+$Map::Tube::London::Line::HammersmithCity::VERSION   = '0.44';
 $Map::Tube::London::Line::HammersmithCity::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::HammersmithCity - London Tube Map Hammersmith & City Li
 
 =head1 VERSION
 
-Version 0.43
+Version 0.44
 
 =head1 DESCRIPTION
 
@@ -87,7 +87,8 @@ London Tube Map Hammersmith & City Line stations.
 
 =head1 MAP
 
-London Metro: Hammersmith & City line map generated by plugin L<Map::Tube::Plugin::Graph>.
+London Metro: L<Hammersmith & City|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/HammersmithCity.png>
+line map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
