@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Jubilee;
 
-$Map::Tube::London::Line::Jubilee::VERSION   = '0.43';
+$Map::Tube::London::Line::Jubilee::VERSION   = '0.44';
 $Map::Tube::London::Line::Jubilee::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Jubilee - London Tube Map Jubilee Line stations.
 
 =head1 VERSION
 
-Version 0.43
+Version 0.44
 
 =head1 DESCRIPTION
 
@@ -79,7 +79,8 @@ London Tube Map Jubilee Line stations.
 
 =head1 MAP
 
-London Metro: Jubilee line map generated by plugin L<Map::Tube::Plugin::Graph>.
+London Metro: L<Jubilee|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Jubilee.png>
+line map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
