@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Metropolitan;
 
-$Map::Tube::London::Line::Metropolitan::VERSION   = '0.43';
+$Map::Tube::London::Line::Metropolitan::VERSION   = '0.44';
 $Map::Tube::London::Line::Metropolitan::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Metropolitan - London Tube Map Metropolitan Line statio
 
 =head1 VERSION
 
-Version 0.43
+Version 0.44
 
 =head1 DESCRIPTION
 
@@ -81,7 +81,8 @@ London Tube Map Metropolitan Line stations.
 
 =head1 MAP
 
-London Metro: Metropoiltan line map generated by plugin L<Map::Tube::Plugin::Graph>.
+London Metro: L<Metropoiltan|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Metropolitan.png>
+line map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
